Dictionary conventions
=========================

Dictionary file naming convention
------------------------------------

The order of dictionaries is important for the order in which variables and families are created.

The files must therefore be started with two numbers followed by a hyphen.

For example: `00-base.xml`

Naming convention for families and variables
-----------------------------------------------

The only restriction on the name of families and variables is that the name must not start with the `"_"` (undescore) character. 

However, it is preferable to only use lowercase ASCII letters, numbers and the `"_"` (undescore) character. 
The snake case typographic convention is therefore used.
